@@ -182,12 +182,11 @@ class FormHXRequest(HXRequestGET, HXRequestPOST):
         For when the form is invalid
         """
         headers = super().get_GET_headers()
-        if (
-            self.request.method == "POST"
-            and self._use_hx_messages
-            and self.show_messages
-        ):
-            headers.update(self.get_message_headers(**kwargs))
+        if self.request.method == "POST":
+            if self._use_hx_messages and self.show_messages:
+                headers.update(self.get_message_headers(**kwargs))
+            if self.no_swap:
+                headers["HX-Reswap"] = "none"
         return headers
 
     def get_form_kwargs(self, **kwargs):
@@ -260,15 +259,15 @@ class HXModal(HXRequestGET):
     modal_template = getattr(
         settings, "HX_REQUSTS_MODAL_TEMPLATE", "hx_requests/modal.html"
     )
-    modal_wrapper_id = getattr(
-        settings, "HX_REQUSTS_MODAL_WRAPPER_ID", "hx_modal_wrapper"
+    modal_container_id = getattr(
+        settings, "HX_REQUSTS_MODAL_CONTAINER_ID", "hx_modal_container"
     )
 
     def get_GET_context_data(self, **kwargs) -> Dict:
         context = super().get_context_data(**kwargs)
         body = kwargs.get("body", self.GET_template)
         context["title"] = kwargs.get("title", self.hx_object)
-        context["modal_wrapper_id"] = self.modal_wrapper_id
+        context["modal_container_id"] = self.modal_container_id
         context["body"] = (
             render_to_string(body, context=context)
             if body.split(".")[-1] == "html"
