@@ -23,33 +23,31 @@ class HtmxViewMixin(View):
 
     def get(self, request: HttpRequest, *args: Any, **kwargs: Any) -> HttpResponse:
         if is_htmx_request(request):
-            super().get(request, *args, **kwargs)
-            hx_request = self.get_hx_request(request)
-            hx_request.view = self
+            hx_request = self._setup_hx_request(request, *args, **kwargs)
             kwargs = self.get_extra_kwargs(request)
-            hx_request.setup_hx_request(request)
             return hx_request.get(request, *args, **kwargs)
         return super().get(request, *args, **kwargs)
 
     def post(self, request: HttpRequest, *args: Any, **kwargs: Any) -> HttpResponse:
         if is_htmx_request(request):
-            # Call get to setup neccessary parts for the context
-            super().get(request, *args, **kwargs)
-            hx_request = self.get_hx_request(request)
-            hx_request.view = self
+            hx_request = self._setup_hx_request(request, *args, **kwargs)
             kwargs = self.get_extra_kwargs(request)
-            hx_request.setup_hx_request(request)
             return hx_request.post(request, *args, **kwargs)
         return super().post(request, *args, **kwargs)
 
     def get_hx_request(self, request):
         hx_request_name = request.GET.get("hx_request_name")
         self._get_hx_reqeust_classes()
-        hx_request = next(
-            hx_request
-            for name, hx_request in self.hx_requests.items()
-            if name == hx_request_name
-        )
+        try:
+            hx_request = next(
+                hx_request
+                for name, hx_request in self.hx_requests.items()
+                if name == hx_request_name
+            )
+        except StopIteration:
+            raise Exception(
+                f"No HXRequest found with the name {hx_request_name}. Are you sure it's spelled correctly?"
+            )
         return hx_request()
 
     @classmethod
@@ -79,3 +77,11 @@ class HtmxViewMixin(View):
             kwargs[key] = request.GET.get(key)
 
         return deserialize_kwargs(**kwargs)
+
+    def _setup_hx_request(self, request, *args, **kwargs):
+        # Call get even on post to setup neccessary parts for the context
+        super().get(request, *args, **kwargs)
+        hx_request = self.get_hx_request(request)
+        hx_request.view = self
+        hx_request.setup_hx_request(request)
+        return hx_request
